@@ -393,7 +393,7 @@ that LW/CMU automatically converts strings from c-calls."
   `(new-ptr ,size)
   )
 
-(defun foreign-string-length (foreign-string)
+(defmacro foreign-string-length (foreign-string)
   #+allegro `(ff:foreign-strlen ,foreign-string)
   #-allegro
   `(loop
